@@ -50,25 +50,14 @@
 #include "hcp-rfs.h"
 #endif
 
-#define HCP_WINDOW_GET_PRIVATE(object) \
-        (G_TYPE_INSTANCE_GET_PRIVATE ((object), HCP_TYPE_WINDOW, HCPWindowPrivate))
-
-G_DEFINE_TYPE (HCPWindow, hcp_window, HILDON_TYPE_STACKABLE_WINDOW);
-
-struct _HCPWindowPrivate 
-{
-  HCPApp         *focused_item;
-  HCPAppList     *al;
-  GtkWidget      *view;
-
-  /* For state save data */
-  gchar          *saved_focused_filename;
-  gint            scroll_value;
-};
-
 #define HCP_TITLE             _("copa_ap_cp_name")
 #define HCP_MENU_RFS          _("copa_me_tools_rfs")
 #define HCP_MENU_CUD          _("copa_me_tools_cud")
+#if HCP_WITH_SIM
+#define HCP_MENU_SIM          dgettext("osso-connectivity-ui",\
+                                  "conn_ti_enter_sim_unlock_code")
+#endif
+
 
 #define HCP_STATE_GROUP         "HildonControlPanel"
 #define HCP_STATE_FOCUSED       "Focussed"
@@ -85,6 +74,27 @@ struct _HCPWindowPrivate
 #define HCP_CUD_SCRIPT         "/usr/sbin/osso-app-killer-cud.sh"
 #define HCP_SCREENSHOT_PATH    "/home/user/.cache/launch/com.nokia.controlpanel.pvr"
 
+#define HCP_SIM_SCRIPT         "/usr/bin/startup-pin-query"
+
+#define HCP_WITH_ROS           1
+#define HCP_WITH_CUD           0
+
+#define HCP_WINDOW_GET_PRIVATE(object) \
+        (G_TYPE_INSTANCE_GET_PRIVATE ((object), HCP_TYPE_WINDOW, HCPWindowPrivate))
+
+G_DEFINE_TYPE (HCPWindow, hcp_window, HILDON_TYPE_STACKABLE_WINDOW);
+
+struct _HCPWindowPrivate 
+{
+  HCPApp         *focused_item;
+  HCPAppList     *al;
+  GtkWidget      *view;
+
+  /* For state save data */
+  gchar          *saved_focused_filename;
+  gint            scroll_value;
+};
+
 static void 
 hcp_window_enforce_state (HCPWindow *window)
 {
@@ -369,6 +379,7 @@ hcp_window_keyboard_listener (GtkWidget * widget,
 }
 
 #ifdef MAEMO_TOOLS
+#if HCP_WITH_CUD
 static gboolean 
 hcp_window_clear_user_data (GtkWidget *widget, HCPWindow *window)
 {
@@ -378,7 +389,8 @@ hcp_window_clear_user_data (GtkWidget *widget, HCPWindow *window)
 
   return TRUE;
 }
-
+#endif
+#if HCP_WITH_ROS
 static gboolean 
 hcp_window_reset_factory_settings (GtkWidget *widget, HCPWindow *window)
 {
@@ -388,8 +400,17 @@ hcp_window_reset_factory_settings (GtkWidget *widget, HCPWindow *window)
 
   return TRUE;
 }
-
 #endif
+#if HCP_WITH_SIM
+static gboolean 
+hcp_window_sim_unlock (GtkWidget *widget, HCPWindow *window)
+{
+  textdomain(PACKAGE);
+  hcp_rfs_simlock ();
+  return TRUE;
+}
+#endif
+#endif /* ifdef MAEMO_TOOLS */
 
 static void 
 hcp_window_topmost_status_change (GObject *gobject, 
@@ -576,29 +597,54 @@ hcp_window_construct_ui (HCPWindow *window)
 #ifdef MAEMO_TOOLS
 
   /* Reset Factory Settings */
-  mi = hildon_button_new_with_text (HILDON_SIZE_AUTO_WIDTH |
-									HILDON_SIZE_FINGER_HEIGHT, 
-									HILDON_BUTTON_ARRANGEMENT_VERTICAL,
-									HCP_MENU_RFS, NULL);
+#if HCP_WITH_ROS
+  mi = hildon_button_new (HILDON_SIZE_AUTO_WIDTH |
+						  HILDON_SIZE_FINGER_HEIGHT,
+  						  HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+
+  GtkWidget *ros_label = gtk_label_new (HCP_MENU_RFS);
+  gtk_label_set_justify (GTK_LABEL(ros_label), GTK_JUSTIFY_CENTER );
+
+  gtk_container_add (GTK_CONTAINER(mi), ros_label);
+ 
   hildon_helper_set_logical_font (mi, "SmallSystemFont");
  
   hildon_app_menu_append (menu, GTK_BUTTON(mi));
 
   g_signal_connect (mi, "clicked",
                     G_CALLBACK (hcp_window_reset_factory_settings), window);
-
-  /* Clean User Data */
+#endif
+  /* Clear User Data */
+#if HCP_WITH_CUD
   mi = hildon_button_new_with_text (HILDON_SIZE_AUTO_WIDTH |
 									HILDON_SIZE_FINGER_HEIGHT, 
 									HILDON_BUTTON_ARRANGEMENT_VERTICAL,
 									HCP_MENU_CUD, NULL);
-  hildon_helper_set_logical_font (mi, "SmallSystemFont");
 
   hildon_app_menu_append (menu, GTK_BUTTON(mi));
 
   g_signal_connect (mi, "clicked",
                     G_CALLBACK (hcp_window_clear_user_data), window);
 #endif
+  /* unlock device */
+#if HCP_WITH_SIM
+  mi = hildon_button_new (HILDON_SIZE_AUTO_WIDTH |
+						  HILDON_SIZE_FINGER_HEIGHT,
+  						  HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+
+  GtkWidget *sim_label = gtk_label_new (HCP_MENU_SIM);
+  gtk_label_set_justify (GTK_LABEL(sim_label), GTK_JUSTIFY_CENTER );
+
+  gtk_container_add (GTK_CONTAINER(mi), sim_label);
+
+  hildon_helper_set_logical_font (mi, "SmallSystemFont");
+
+  hildon_app_menu_append (menu, GTK_BUTTON(mi));
+
+  g_signal_connect (mi, "clicked",
+                    G_CALLBACK (hcp_window_sim_unlock), window);
+#endif /* if HCP_WITH_SIM */
+#endif /* ifdef MAEMO_TOOLS */
   
   gtk_widget_show_all (GTK_WIDGET (menu));
 
